@@ -30,20 +30,22 @@ import argparse
 from yconf.util import NestedDict
 
 
-class _Loader(yaml.Loader):
+class _Loader(yaml.SafeLoader):
 
     def __init__(self, *args, **kwargs):
-        yaml.Loader.__init__(self, *args, **kwargs)
+        super(_Loader, self).__init__(*args, **kwargs)
 
     def construct_mapping(self, node, deep=False):
-        mapping = yaml.Loader.construct_mapping(self, node, deep)
-        for key in mapping:
-            if type(key) == str:
+        result = dict()
+        mapping = super(_Loader, self).construct_mapping(node, deep)
+        for key, value in mapping.items():
+            result[key] = value
+            if type(key) == str and "-" in key:
                 new = key.replace("-", "_")
-                if new != key:
-                    mapping[new] = mapping[key]
-                    del mapping[key]
-        return mapping
+                if new in mapping:
+                    raise Exception("Key '%s' causes a mapping conflict with key '%s'." % (new, key))
+                result[new] = value
+        return result
 
 
 PRODUCTION  = 10
